@@ -464,7 +464,7 @@ static xcb_atom_t best_atom_from_target(xcb_atom_t* list, size_t size)
         return a;
     }
 
-    //selecting loseless formats first
+    //selecting lossless formats first
     if((a=target_has_atom(list, size, ATOM_IMAGE_PNG)))
     {
 //         EPHYR_DBG( "selecting mime type image/png");
@@ -558,7 +558,7 @@ void read_selection_property(xcb_atom_t selection, xcb_atom_t property)
                 remoteVars->selstruct.incrementalSize=sz;
                 remoteVars->selstruct.incrementalSizeRead=0;
 
-                //deleteing property should tell the selection owner that we are ready for incremental reading of data
+                //deleting property should tell the selection owner that we are ready for incremental reading of data
                 xcb_delete_property(remoteVars->selstruct.xcbConnection,remoteVars->selstruct.clipWinId, property);
                 xcb_flush(remoteVars->selstruct.xcbConnection);
                 free(reply);
@@ -614,7 +614,7 @@ void read_selection_property(xcb_atom_t selection, xcb_atom_t property)
                             else
                             {
                                 //request selection data
-//                                 EPHYR_DBG("client not supports onDemand selection, request data");
+//                                 EPHYR_DBG("client doesn't support onDemand selection, requesting data");
                                 request_selection_data( selection, data_atom, data_atom, 0);
                             }
                         }
@@ -688,7 +688,7 @@ void read_selection_property(xcb_atom_t selection, xcb_atom_t property)
                             remoteVars->selstruct.incrementalSizeRead+=xcb_get_property_value_length(reply);
                             if(!bytes_left && ! bytes_read && !xcb_get_property_value_length(reply))
                             {
-                                //we got the property with 0 size it means that we recieved all data of incr property
+                                //we got the property with 0 size it means that we received all data of incr property
 //                                 EPHYR_DBG("INCR Property done, read %d", remoteVars->selstruct.incrementalSizeRead);
                                 remoteVars->selstruct.incrAtom=0;
                                 remoteVars->selstruct.incrementalSize=0;
@@ -751,7 +751,7 @@ void read_selection_property(xcb_atom_t selection, xcb_atom_t property)
                 }
                 else
                 {
-                    EPHYR_DBG("Not supported mime type:%d",reply->type);
+                    EPHYR_DBG("Unsupported mime type: %d",reply->type);
                 }
             }
             if(reply)
@@ -817,7 +817,7 @@ void process_selection_notify(xcb_generic_event_t *e)
 
     if(sel_event->property== sel_event->selection && sel_event->target==sel_event->selection)
     {
-        //have data ready from server. We don't need to do anything here. This event interrrupted the waiting procedure and the delayed requests are already processed
+        //have data ready from server. We don't need to do anything here. This event interrupted the waiting procedure and the delayed requests are already processed
 //         EPHYR_DBG("Have DATA READY event");
         return;
     }
@@ -868,7 +868,7 @@ void process_property_notify(xcb_generic_event_t *e)
 //         EPHYR_DBG( "NEW VALUE");
         if(remoteVars->selstruct.incrAtom==pn->atom && remoteVars->selstruct.incrementalSize)
         {
-            //we recieveing the selection data incrementally, let's read a next chunk
+            //we're receiving the selection data incrementally, let's read the next chunk
 //             EPHYR_DBG("reading incr property %d", pn->atom);
             read_selection_property(remoteVars->selstruct.currentSelection, pn->atom);
         }
@@ -910,7 +910,7 @@ void process_selection_owner_notify(xcb_generic_event_t *e)
 
     selection=selection_from_atom(notify_event->selection);
 
-    //we are not owners of this selction anymore
+    //we are not owners of this selection anymore
 
     pthread_mutex_lock(&remoteVars->selstruct.inMutex);
     remoteVars->selstruct.inSelection[selection].owner=FALSE;
@@ -944,7 +944,7 @@ void *selection_thread (void* id)
     remoteVars->selstruct.xcbConnection = xcb_connect (remoteVars->displayName, NULL);
     if(xcb_connection_has_error(remoteVars->selstruct.xcbConnection))
     {
-        EPHYR_DBG("Warning! can't create XCB connection to display %s, selections exchange between client and server will be disabled", remoteVars->displayName);
+        EPHYR_DBG("Warning! Can't create XCB connection to display %s, selections exchange between client and server will be disabled", remoteVars->displayName);
         remoteVars->selstruct.xcbConnection=0;
         pthread_exit(0);
         return NULL;
@@ -957,7 +957,7 @@ void *selection_thread (void* id)
 
     init_atoms();
 
-    //create window which will recieve selection events and provide remote selection to X-clients
+    //create window which will receive selection events and provide remote selection to X clients
     xcb_create_window (remoteVars->selstruct.xcbConnection,
                        XCB_COPY_FROM_PARENT,
                        remoteVars->selstruct.clipWinId,
@@ -970,7 +970,7 @@ void *selection_thread (void* id)
                        mask, values);
 
     xcb_flush(remoteVars->selstruct.xcbConnection);
-    //check if we have xfixes, we need it to recieve selection owner events
+    //check if we have xfixes, we need it to receive selection owner events
     reply = xcb_get_extension_data(remoteVars->selstruct.xcbConnection, &xcb_xfixes_id);
     if (reply && reply->present)
     {
@@ -982,7 +982,7 @@ void *selection_thread (void* id)
         }
         else
         {
-            //we'll recieve sel owner events for primary amd clipboard
+            //we'll receive sel owner events for primary and clipboard
             mask =  XCB_XFIXES_SELECTION_EVENT_MASK_SET_SELECTION_OWNER;
             xcb_xfixes_select_selection_input_checked(remoteVars->selstruct.xcbConnection,remoteVars->selstruct.clipWinId, XCB_ATOM_PRIMARY, mask);
             xcb_xfixes_select_selection_input_checked(remoteVars->selstruct.xcbConnection, remoteVars->selstruct.clipWinId, ATOM_CLIPBOARD, mask);
@@ -998,19 +998,19 @@ void *selection_thread (void* id)
         remove_obsolete_incr_transactions(TRUE);
         response_type = e->response_type & ~0x80;
 
-        //we notified that selection is changed in primary or clipboard
+        //we're notified that selection has changed in primary or clipboard
         if (response_type == reply->first_event + XCB_XFIXES_SELECTION_NOTIFY)
         {
             process_selection_owner_notify(e);
         }
         else
         {
-            //we notified that property is changed
+            //we're notified that property has changed
             if (response_type == XCB_PROPERTY_NOTIFY)
             {
                 process_property_notify(e);
             }
-            //we got reply to our selection request (mime types or data)
+            //we've got a reply to our selection request (mime types or data)
             else if (response_type == XCB_SELECTION_NOTIFY)
             {
                 process_selection_notify(e);
@@ -1019,7 +1019,7 @@ void *selection_thread (void* id)
             {
                 if(!process_selection_request(e))
                 {
-                    //we delayed this request, not deleteing the event yet
+                    //we delayed this request, not deleting the event yet
                     continue;
                 }
             }
@@ -1047,7 +1047,7 @@ void install_selection_callbacks(void)
     ret = pthread_create(&(remoteVars->selstruct.selThreadId), NULL, selection_thread, (void *)remoteVars->selstruct.selThreadId);
     if (ret)
     {
-        EPHYR_DBG("ERROR; return code from pthread_create() is %d", ret);
+        EPHYR_DBG("ERROR; return code of pthread_create() is %d", ret);
         remoteVars->selstruct.selThreadId=0;
     }
     else
@@ -1284,7 +1284,7 @@ xcb_atom_t send_data(xcb_selection_request_event_t* req)
             free(starget);
 */
 
-        //TODO: implement convertion between different image formats
+        //TODO: implement conversion between different image formats
         if(is_png(remoteVars->selstruct.inSelection[sel].data, remoteVars->selstruct.inSelection[sel].size))
         {
             if(req->target!=ATOM_IMAGE_PNG)
@@ -1390,7 +1390,7 @@ void start_incr_transaction(xcb_window_t requestor, xcb_atom_t property, xcb_ato
     }
 
 
-    //we'll recive property change events for requestor window from now
+    //we'll receive property change events for requestor window from now
     xcb_change_window_attributes(remoteVars->selstruct.xcbConnection, requestor,
                                  XCB_CW_EVENT_MASK, mask);
 }
@@ -1407,7 +1407,7 @@ unsigned char* zcompress(unsigned char *inbuf, uint32_t size, uint32_t* compress
 {
     //compressing the data with zlib
     //return compressed data, storing the size of compressed data in compress_size
-    //caller function should chek result of compression and free the output buffer
+    //caller function should check result of compression and free the output buffer
 
 
     //out buffer at least the size of input buffer
